/****************************************************************************


usb2185.rc

produced by Borland Resource Workshop


*****************************************************************************/

/*#define USB2185_ERROR_ID_135	135*/
#define USB2185_ERROR_ID_134	134
#define USB2185_ERROR_ID_133	133
#define USB2185_ERROR_ID_132	132
#define USB2185_ERROR_ID_131	131
#define USB2185_ERROR_ID_130	130
#define USB2185_ERROR_ID_129	129
#define USB2185_ERROR_ID_128	128
#define USB2185_ERROR_ID_127	127
#define USB2185_ERROR_ID_126	126
#define USB2185_ERROR_ID_125	125
#define USB2185_ERROR_ID_124	124
#define USB2185_ERROR_ID_123	123
#define USB2185_ERROR_ID_122	122
#define USB2185_ERROR_ID_121	121
#define USB2185_ERROR_ID_120	120
#define USB2185_ERROR_ID_119	119
#define USB2185_ERROR_ID_118	118
#define USB2185_ERROR_ID_117	117
#define USB2185_ERROR_ID_116	116
#define USB2185_ERROR_ID_115	115
#define USB2185_ERROR_ID_114	114
#define USB2185_ERROR_ID_113	113
#define USB2185_ERROR_ID_112	112
#define USB2185_ERROR_ID_111	111
#define USB2185_ERROR_ID_110	110
#define USB2185_ERROR_ID_109	109
#define USB2185_ERROR_ID_108	108
#define USB2185_ERROR_ID_107	107
#define USB2185_ERROR_ID_106	106
#define USB2185_ERROR_ID_105	105
#define USB2185_ERROR_ID_104	104
#define USB2185_ERROR_ID_103	103
#define USB2185_ERROR_ID_102	102
#define USB2185_ERROR_ID_101	101
#define USB2185_ERROR_ID_100	100

//------------------------------------------------------------------------------
// описание возможных ошибок библиотеки при работе с модулем USB-2185
//------------------------------------------------------------------------------
STRINGTABLE
{
 USB2185_ERROR_ID_100, "В Багдаде все спокойно! УРА!!!"
 USB2185_ERROR_ID_101, "Для работы модуля USB2185 требуется Windows'2000/XP/Vista."
 USB2185_ERROR_ID_102, "Не могу открыть виртуальный слот модуля."
 USB2185_ERROR_ID_103, "Не могу выполнить WinAPI функцию CloseHandle()."
 USB2185_ERROR_ID_104, "Нет доступа к виртуальному слоту модуля."
 USB2185_ERROR_ID_105, "Не могу выполнить WinAPI функцию DeviceIoControl()."
 USB2185_ERROR_ID_106, "Не выполнена функция RESET_DSP()."
 USB2185_ERROR_ID_107, "Не могу найти ресурс с кодом драйвера DSP."
 USB2185_ERROR_ID_108, "Не могу загрузить ресурс с кодом драйвера DSP."
 USB2185_ERROR_ID_109, "Не могу зафиксировать в памяти ресурс с кодом драйвера DSP."
 USB2185_ERROR_ID_110, "Не могу определить длину ресурса с кодом драйвера DSP."
 USB2185_ERROR_ID_111, "Не могу выделить буфер под драйвер DSP."
 USB2185_ERROR_ID_112, "Не могу открыть файл с драйвером DSP."
 USB2185_ERROR_ID_113, "Не могу определить длину файла с драйвером DSP."
 USB2185_ERROR_ID_114, "Не могу прочитать файл с драйвером DSP."
 USB2185_ERROR_ID_115, "Не выполнена функция PUT_DM_ARRAY(). Не загружен сегмент данных драйвера DSP."
 USB2185_ERROR_ID_116, "Не выполнена функция PUT_PM_ARRAY(). Не загружен сегмент кода драйвера DSP."
 USB2185_ERROR_ID_117, "Не выполнена функция GET_PM_WORD(). Не прочитан базовый адрес сегмента кода драйвера DSP."
 USB2185_ERROR_ID_118, "Не выполнена функция GET_VAR_WORD()."
 USB2185_ERROR_ID_119, "После загрузки модуля драйвер DSP вернул неправильные тестовые значения."
 USB2185_ERROR_ID_120, "Не выполнена функция PUT_VAR_WORD()."
 USB2185_ERROR_ID_121, "Таймаут готовности модуля после загрузки драйвера DSP."
 USB2185_ERROR_ID_122, "Не выполнилась функция SEND_COMMAND()."
 USB2185_ERROR_ID_123, "Тестовая команда с номером 0x0 вернула неправильное значение."
 USB2185_ERROR_ID_124, "Недопустимый номер команды для штатного драйвера DSP."
 USB2185_ERROR_ID_125, "Таймаут выполнения команды DSP."
 USB2185_ERROR_ID_126, "Не совпадает размер (поле size) структуры FLASH."

 USB2185_ERROR_ID_127, "Не выполнена функция GET_FLASH_WORD()."
 USB2185_ERROR_ID_128, "Не выполнена функция PUT_FLASH_WORD()."

 USB2185_ERROR_ID_129, "Недопустимый адрес переменной драйвера DSP."
 USB2185_ERROR_ID_130, "Не выполнилась функция PUT_PM_WORD()."
 USB2185_ERROR_ID_131, "Не выполнилась функция GET_PM_WORD()."

 USB2185_ERROR_ID_132, "Неправильный заголовок файла c драйвером DSP (*.rtd)."
 USB2185_ERROR_ID_133, "Не могу прочитать название текущего модуля."
 USB2185_ERROR_ID_134, "В данном виртуальном слоте не USB2185 модуль."
};

//------------------------------------------------------------------------------
// образ файла c кодом драйвера DSP для модуля USB-2185
//------------------------------------------------------------------------------
USB2185DSP RCDATA usb2185.rtd

